// Class contains information about a currency.
function Currency(currencyData) {
    var self = this;
    self.currencyData = ko.observable(currencyData);
}

function CurrencyViewModel() {
    var self = this;

    // Non-editable catalog data about currencies.
    self.availableCurrencies = [];

    self.currencies = ko.observableArray([]);

    self.allCurrencies = ko.computed(function(){
        var total = "";
        ko.utils.arrayForEach(self.currencies(), function(item) {
            total += item.currencyData().currencyName + ";";
        });
        return total.substring(0, total.length - 1);
    });

    self.addCurrency = function() {
        if (!hasAvailableCurrencies()) {
            return;
        }
        self.currencies.push(new Currency(self.availableCurrencies[0]));
    };

    self.removeCurrency = function(currency) {
        self.currencies.remove(currency)
    };

    $.ajax({
        type: 'GET',
        url: "http://" + window.location.host + "/static-data/currencies.json",
        dataType: "json",
        success: function(data){
            updateAvailableCurrencies(data);
            initDeviceCurrencies();
        }
    });

    // Update available currencies list by data from a json file.
    function updateAvailableCurrencies(data) {
        var currencies = data.currencies;
        for (var i = 0; i < currencies.length; i++) {
            self.availableCurrencies.push({currencyName: currencies[i].ISO_Char_Code})
        }
    }

    // Show the device currencies on the screen.
    function initDeviceCurrencies() {
        if (!hasAvailableCurrencies()) {
            return;
        }
        var deviceCurrencies = getCurrencyData();
        if (deviceCurrencies) {
            for (var i = 0; i < deviceCurrencies.length; i++) {
                var data = getCurrencyDataByName(deviceCurrencies[i]);
                if (data == null) {
                    continue;
                }
                self.currencies.push(new Currency(data));
            }
        }
    }

    // Get an object with currency data by name or null.
    // (Knockout library require a object from the availableCurrencies list
    // for correct working)
    function getCurrencyDataByName(currencyName) {
        for (var i = 0; i < self.availableCurrencies.length; i++) {
            if (self.availableCurrencies[i].currencyName == currencyName)
                return self.availableCurrencies[i];
        }
        return null;
    }

    // Return true if list has one or more available currencies.
    function hasAvailableCurrencies() {
        return self.availableCurrencies.length != 0;
    }
}

(function() {
    var currencyViewModel = new CurrencyViewModel();
    if (document.getElementById("currency-editor") !== null) {
        ko.applyBindings(currencyViewModel, document.getElementById("currency-editor"));
        ko.applyBindings(currencyViewModel, document.getElementById("currency-values"));
    }
})()
