// Class contains information about a petrol.
function Petrol(petrolData) {
    var self = this;
    self.petrolData = ko.observable(petrolData);
}

function PetrolViewModel() {
    var self = this;

    // Non-editable catalog data about petrols.
    self.availablePetrols = [];

    self.petrols = ko.observableArray([]);

    self.allPetrols = ko.computed(function(){
        var total = "";
        ko.utils.arrayForEach(self.petrols(), function(item) {
            total += item.petrolData().petrolName + ";";
        });
        return total.substring(0, total.length - 1);
    });

    self.addPetrol = function() {
        if (!hasAvailablePetrols()) {
            return;
        }
        self.petrols.push(new Petrol(self.availablePetrols[0]));
    };

    self.removePetrol = function(petrol) {
        self.petrols.remove(petrol)
    };

    updateAvailablePetrols($("#petrol-list").attr("value").split(";"))
    initDevicePetrols()

    // Update available petrols list by data from a json file.
    function updateAvailablePetrols(petrols) {
        for (var i = 0; i < petrols.length; i++) {
            self.availablePetrols.push({petrolName: petrols[i]})
        }
    }

    // Show the device petrols on the screen.
    function initDevicePetrols() {
        if (!hasAvailablePetrols()) {
            return;
        }
        var devicePetrols = getPetrolData();
        if (devicePetrols) {
            for (var i = 0; i < devicePetrols.length; i++) {
                var data = getPetrolDataByName(devicePetrols[i]);
                if (data == null) {
                    continue;
                }
                self.petrols.push(new Petrol(data));
            }
        }
    }

    // Get an object with petrol data by name or null.
    // (Knockout library require a object from the availablePetrols list
    // for correct working)
    function getPetrolDataByName(petrolName) {
        for (var i = 0; i < self.availablePetrols.length; i++) {
            if (self.availablePetrols[i].petrolName == petrolName)
                return self.availablePetrols[i];
        }
        return null;
    }

    // Return true if list has one or more available petrols.
    function hasAvailablePetrols() {
        return self.availablePetrols.length != 0;
    }
}

(function() {
    var petrolViewModel = new PetrolViewModel();
    if (document.getElementById("petrol-editor") !== null) {
        ko.applyBindings(petrolViewModel, document.getElementById("petrol-editor"));
        ko.applyBindings(petrolViewModel, document.getElementById("petrol-values"));
    }
})()
